@@ -18,6 +18,7 @@ pygtk.require("2.0")
 import gobject, gtk
 import xdg.BaseDirectory
 import shutil
+import PlatformUtils
 
 import gettext
 _ = gettext.gettext
@@ -36,8 +37,13 @@ class Settings:
 				"projectfolder" : "",
 				"windowheight" : 550,
 				"windowwidth" : 900,
+				"addinstrumentwindowheight" : 350,
+				"addinstrumentwindowwidth" : 300,
+				"instrumenteffectwindowheight" : 450,				
+				"instrumenteffectwindowwidth" : 650,
+				
 				}
-	
+
 	recording = {
 				"fileformat": "flacenc",
 				"file_extension": "flac",
@@ -45,13 +51,17 @@ class Settings:
 				"audiosrc" : "gconfaudiosrc",
 				"device" : "default"
 				}
+	# Overwrite with platform specific settings
+	recording.update( PlatformUtils.GetRecordingDefaults() )
 	
 	playback = 	{
 				"devicename": "default",
 				"device": "default",
 				"audiosink":"autoaudiosink"
 				}
-	
+	# Overwrite with platform specific settings
+	playback.update( PlatformUtils.GetPlaybackDefaults() )
+
 	extensions = {
 				 "extensions_blacklist": ""
 				 }
@@ -144,25 +154,6 @@ def FAT32SafeFilename(filename):
 	return "".join([x for x in filename if x in allowedChars])
 
 #_____________________________________________________________________
-		
-def PrintPipelineDebug(message, pipeline):
-	"""
-	Prints debugging information for the GStreamer pipeline.
-	
-	Parameters:
-		message -- GStreamer message to be printed as debugging output.
-		pipeline -- the currently active Project's main pipeline.
-	"""
-	try:
-		if os.environ['JOKOSHER_DEBUG']:
-			import JokDebug
-			jokDebug = JokDebug.JokDebug()
-			debug(message)
-			jokDebug.ShowPipelineTree(pipeline)
-	except:
-		pass
-
-#_____________________________________________________________________
 
 #static list of all the Instrument files (to prevent having to reimport files).
 instrumentPropertyList = []
@@ -356,7 +347,7 @@ def CheckBackendList(backend_list):
 def CopyAllFiles(src_dir, dest_dir, only_these_files=None):
 	""" Copies all the files, but only the files from one directory to another."""
 	for file in os.listdir(src_dir):
-		if only_these_files and file not in only_these_files:
+		if only_these_files is not None and file not in only_these_files:
 			continue
 		
 		src_path = os.path.join(src_dir, file)
@@ -699,6 +690,7 @@ EXPORT_FORMATS = []
 
 SAMPLE_RATES = [8000, 11025, 22050, 32000, 44100, 48000, 96000, 192000]
 
+
 PLAYBACK_BACKENDS = [
 	(_("Autodetect"), "autoaudiosink"),
 	(_("Use GNOME Settings"), "gconfaudiosink"),
@@ -706,6 +698,8 @@ PLAYBACK_BACKENDS = [
 	("OSS", "osssink"),
 	("JACK", "jackaudiosink"),
 	("PulseAudio", "pulsesink"),
+	("Direct Sound", "directsoundsink"),
+	("Core Audio", "osxaudiosink")
 ]
 
 CAPTURE_BACKENDS = [
@@ -714,6 +708,8 @@ CAPTURE_BACKENDS = [
 	("OSS", "osssrc"),
 	("JACK", "jackaudiosrc"),
 	("PulseAudio", "pulsesrc"),
+	("Direct Sound", "dshowaudiosrc"),
+	("Core Audio", "osxaudiosrc")
 ]
 
 """ Default Instruments """
