@@ -12,7 +12,7 @@
 import gtk.glade
 import os
 import ProjectManager
-import pwd
+import PlatformUtils
 import Globals
 import gettext
 _ = gettext.gettext
@@ -54,7 +54,6 @@ class NewProjectDialog:
 		
 		self.name = self.res.get_widget("name")
 		self.name.set_activates_default(True)
-		self.folder = self.res.get_widget("folder")
 		self.author = self.res.get_widget("author")
 		self.author.set_activates_default(True)
 		
@@ -75,22 +74,20 @@ class NewProjectDialog:
 		self.templatecombo.add_attribute(text, "text", 0)
 		
 		self.templatecombo.set_active(0)
-		
+
 		# Default author to name of currently logged in user
-		try:
-			# Try to get the full name if it exists
-			fullname = pwd.getpwuid(os.getuid())[4].split(",")[0]
-			if fullname == "":
-				fullname = pwd.getpwuid(os.getuid())[0]
-			self.author.set_text(fullname)
-		except:
-			# If we can't get the fullname, then just use the login
-			self.author.set_text(pwd.getpwuid(os.getuid())[0])
+		self.author.set_text(PlatformUtils.getFullName())
 		
 		self.okbutton = self.res.get_widget("okButton")
 		self.okbutton.set_flags(gtk.CAN_DEFAULT)
 		self.okbutton.grab_default()
 		
+		self.folder = gtk.FileChooserButton(_("Select A Folder"))
+		self.folder.set_local_only(True)
+		self.folder.set_action(gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER)
+		self.res.get_widget("table5").attach(self.folder, 1, 2, 1, 2)
+		self.folder.show()
+		
 		# Set the default folder of 'folder' (a FileChooserButton)
 		if os.path.exists(Globals.settings.general["projectfolder"]):
 			self.folder.set_current_folder(Globals.settings.general["projectfolder"])
@@ -132,13 +129,15 @@ class NewProjectDialog:
 		if not author:
 			author = _("Unknown Author")
 			
-		folder = self.folder.get_current_folder()
+		# CreateNewProject expects a URI	
+		folder = PlatformUtils.pathname2url(self.folder.get_filename())
+		
 		# Save the selected folder as the default folder
 		Globals.settings.general["projectfolder"] = folder
 		Globals.settings.write()
 		if not folder:
 			folder = "~"
-		
+
 		try:
 			project = ProjectManager.CreateNewProject(folder, name, author)
 		except ProjectManager.CreateProjectError, e:
