@@ -315,6 +315,7 @@ class Project(gobject.GObject):
 					devices[default_device].append(instr)
 		
 
+		recbin = 0
 		for device, recInstruments in devices.iteritems():
 			if len(recInstruments) == 0:
 				#Nothing to record on this device
@@ -329,11 +330,13 @@ class Project(gobject.GObject):
 
 			
 			if channelsNeeded > 1: #We're recording from a multi-input device
-				recordingbin = gst.Bin("recording bin")
+				#Need multiple recording bins with unique names when we're
+				#recording from multiple devices
+				recordingbin = gst.Bin("recordingbin_%d" % recbin)
 				recordString = Globals.settings.recording["audiosrc"]
 				srcBin = gst.parse_bin_from_description(recordString, True)
 				try:
-					src_element = recordingbin.iterate_sources().next()
+					src_element = srcBin.iterate_sources().next()
 				except StopIteration:
 					pass
 				else:
@@ -370,8 +373,9 @@ class Project(gobject.GObject):
 				
 				split.connect("pad-added", self.__RecordingPadAddedCb, recInstruments, recordingbin)
 				Globals.debug("Recording in multi-input mode")
-				Globals.debug("adding recordingbin")
+				Globals.debug("adding recordingbin_%d" % recbin)
 				self.mainpipeline.add(recordingbin)
+				recbin += 1
 			else:
 				instr = recInstruments[0]
 				event = instr.GetRecordingEvent()
@@ -1320,7 +1324,13 @@ class Project(gobject.GObject):
 		if not undoAction:
 			undoAction = self.NewAtomicUndoAction()
 	
-		uris = [PlatformUtils.pathname2url(filename) for filename in fileList]
+		uris = []
+		for filename in fileList:
+			if filename.find("://"):
+				uris.append(filename)
+			else:
+				# We've been passed a path, so convert it to a URI
+				uris.append(PlatformUtils.pathname2url(filename))
 
 		name, type, pixbuf, path = [x for x in Globals.getCachedInstruments() if x[1] == "audiofile"][0]
 		instr = self.AddInstrument(name, type, _undoAction_=undoAction)
