@@ -11,6 +11,7 @@
 import gtk
 import pango
 import cairo
+import gobject
 
 import gettext
 _ = gettext.gettext
@@ -48,21 +49,38 @@ class TimeLine(gtk.DrawingArea):
 	_BEAT_BAR_RGB = (0, 0, 0)
 	_PLAY_CURSOR_RGB = (1, 0, 0)
 	
+	"""
+	   The events we wish to receive after we grab the mouse (and it is no longer above this widget)
+	   If events other than mouse event are put in here, it may cause the program to crash.
+	"""
+	_POINTER_GRAB_EVENTS = (
+			gtk.gdk.POINTER_MOTION_MASK |
+			gtk.gdk.BUTTON_RELEASE_MASK |
+			gtk.gdk.BUTTON_PRESS_MASK)
+	
+	"""Number of milliseconds between each scrollbar update while autoscrolling"""
+	_AUTOSCROLL_UPDATE_INTERVAL = 100
+	
+	"""
+		Speed is relative to distance between mouse and closest edge of the timeline.
+		i.e. The further away you pull your mouse, the faster it scrolls.
+		The speed, multiplied by the mouse's distance, is the amount we scroll each update.
+	"""
+	_AUTOSCROLL_SPEED = 0.2
+	
 	#_____________________________________________________________________
 
-	def __init__(self, project, timelinebar, mainview):
+	def __init__(self, project, mainview):
 		"""
 		Creates a new instance of TimeLine
 		
 		Parameters:
 			project - reference to Project (Project.py)
-			timelinebar - reference of TimeLineBar (TimeLineBar.py)
 			mainview - reference to JokosherApp (JokosherApp.py) - Not used atm.
 		"""
 		gtk.DrawingArea.__init__(self)
 	
 		self.project = project
-		self.timelinebar = timelinebar
 		self.mainview = mainview
 		
 		# Listen for changes in the project and the TransportManager
@@ -75,7 +93,7 @@ class TimeLine(gtk.DrawingArea):
 		
 		self.height = 44
 		self.buttonDown = False
-		self.dragging = False
+		self.current_autoscroll_diff = 0
 
 		# source is an offscreen canvas to hold our waveform image
 		self.source = cairo.ImageSurface(cairo.FORMAT_ARGB32, 0, 0)
@@ -87,9 +105,9 @@ class TimeLine(gtk.DrawingArea):
 		self.SetAccessibleName()
 		self.set_property("can-focus", True)
 	
-		self.set_events(gtk.gdk.POINTER_MOTION_MASK |
-								gtk.gdk.BUTTON_PRESS_MASK |
-								gtk.gdk.BUTTON_RELEASE_MASK)
+		self.set_events(self._POINTER_GRAB_EVENTS)
+		self.set_flags(gtk.CAN_FOCUS)
+		
 		self.connect("expose-event", self.OnDraw)
 		self.connect("button_release_event", self.onMouseUp)
 		self.connect("button_press_event", self.onMouseDown)
@@ -145,10 +163,10 @@ class TimeLine(gtk.DrawingArea):
 		context.paint()
 		
 		# Draw play cursor position (add 1 so it lines up correctly)
-		x = int(round((self.project.transport.position - self.project.viewStart) * self.project.viewScale))+1
-		context.move_to(x, 0)
+		x = self.project.transport.GetPixelPosition()
 		context.set_line_width(1)
-		context.line_to(x, self.allocation.height)
+		context.move_to(x+0.5, 0)
+		context.line_to(x+0.5, self.allocation.height)
 		context.set_antialias(cairo.ANTIALIAS_NONE)
 		context.set_source_rgb(*self._PLAY_CURSOR_RGB)
 		context.stroke()
@@ -374,8 +392,9 @@ class TimeLine(gtk.DrawingArea):
 		if not self.window:
 			return
 		
+		width_in_secs = self.allocation.width / self.project.viewScale
 		# The left and right sides of the viewable area
-		rightPos = self.project.viewStart + self.timelinebar.projectview.scrollRange.page_size
+		rightPos = self.project.viewStart + width_in_secs
 		leftPos = self.project.viewStart
 		currentPos = self.project.transport.GetPosition()
 		
@@ -383,21 +402,21 @@ class TimeLine(gtk.DrawingArea):
 		# Don't autoscroll if "stop-action" is send in extra because that means the 
 		# user just hit stop and did not purposely change the position.
 		if "stop-action" != extraString:
-			if leftPos < self.project.transport.PrevPosition < rightPos:
+			if leftPos < self.project.transport.GetPreviousPosition() < rightPos:
 				if currentPos > rightPos:
 					# now the playhead has moved off to the right, so force the scroll in that direction
-					self.timelinebar.projectview.SetViewPosition(rightPos)
+					self.project.SetViewStart(rightPos)
 			
 				elif currentPos < leftPos:
 					#if playhead is beyond leftmost position then force scroll and quit
-					leftPos = max(0, leftPos - self.timelinebar.projectview.scrollRange.page_size)
-					self.timelinebar.projectview.SetViewPosition(leftPos)
+					leftPos = max(0, leftPos - width_in_secs)
+					self.project.SetViewStart(leftPos)
 	
-		x1 = round((self.project.transport.PrevPosition - self.project.viewStart) * self.project.viewScale)
-		x2 = round((self.project.transport.position - self.project.viewStart) * self.project.viewScale)
+		prev_pos = self.project.transport.GetPreviousPixelPosition()
+		new_pos = self.project.transport.GetPixelPosition()
 	
-		self.queue_draw_area(int(x1)-1, 0, 3, self.get_allocation().height)
-		self.queue_draw_area(int(x2)-1, 0, 3, self.get_allocation().height)
+		self.queue_draw_area(prev_pos - 1, 0, 3, self.get_allocation().height)
+		self.queue_draw_area(new_pos - 1, 0, 3, self.get_allocation().height)
 	
 	#_____________________________________________________________________
 	
@@ -412,11 +431,12 @@ class TimeLine(gtk.DrawingArea):
 		Returns:
 			True -- to continue the GTK signal propagation.
 		"""
-		self.buttonDown = True
-		self.dragging = False
+		
+		response = gtk.gdk.pointer_grab(self.window, False, self._POINTER_GRAB_EVENTS, None, None, event.time)
+		self.buttonDown = (response == gtk.gdk.GRAB_SUCCESS)
+		self.current_autoscroll_diff = 0
 		self.moveHead(event.x)
 		self.grab_focus()
-		
 		return True
 
 	#_____________________________________________________________________
@@ -431,14 +451,43 @@ class TimeLine(gtk.DrawingArea):
 		"""			
 		if not self.buttonDown:
 			return
-		self.dragging = True
 		
-		# prevent playhead being dragged to the window edge - TODO make scrolling actually work!!
-		pos = event.x /self.project.viewScale
-		if (pos > 0.99 * self.timelinebar.projectview.scrollRange.page_size) or (pos < 0.01 * self.timelinebar.projectview.scrollRange.page_size):
-			self.buttonDown = False
-			return
-		self.moveHead(event.x)
+		old_diff = self.current_autoscroll_diff
+		
+		alloc = self.get_allocation()
+		xpos = event.x
+		if 0 < xpos < alloc.width:
+			self.current_autoscroll_diff = 0
+			self.moveHead(xpos)
+		else:
+			if xpos > alloc.width:
+				self.current_autoscroll_diff = (xpos - alloc.width) * self._AUTOSCROLL_SPEED
+			else:
+				self.current_autoscroll_diff = xpos * self._AUTOSCROLL_SPEED
+			
+			if old_diff == 0:
+				gobject.timeout_add(self._AUTOSCROLL_UPDATE_INTERVAL, self.onUpdateAutoscroll)
+		
+	#_____________________________________________________________________
+	
+	def onUpdateAutoscroll(self):
+		if self.current_autoscroll_diff:
+			if self.current_autoscroll_diff > 0:
+				start_xpos = self.current_autoscroll_diff;
+				playhead_xpos = start_xpos + self.allocation.width - 1
+			else:
+				start_xpos = self.current_autoscroll_diff
+				playhead_xpos = start_xpos
+				
+			start = self.project.viewStart + (start_xpos / self.project.viewScale)
+			playhead = self.project.viewStart + (playhead_xpos / self.project.viewScale)
+			
+			self.project.SetViewStart(start)
+			self.project.transport.SeekTo(playhead)
+
+			return True
+		else:
+			return False
 		
 	#_____________________________________________________________________
 		
@@ -450,8 +499,12 @@ class TimeLine(gtk.DrawingArea):
 			widget -- reserved for GTK callbacks, don't use it explicitly.
 			event -- reserved for GTK callbacks, don't use it explicitly.
 		"""
-		self.dragging = False
-		self.buttonDown = False
+		if self.buttonDown:
+			self.buttonDown = False
+			self.current_autoscroll_diff = 0
+			gtk.gdk.pointer_ungrab(event.time)
+		
+		return True
 		
 	#_____________________________________________________________________
 		
@@ -462,7 +515,8 @@ class TimeLine(gtk.DrawingArea):
 		Parameters:
 			xpos -- the time of the new project position.
 		"""
-		pos = self.project.viewStart + xpos/ self.project.viewScale
+		pos = self.project.viewStart + (xpos / self.project.viewScale)
+		pos = max(0., pos)
 		self.project.transport.SeekTo(pos)
 		self.SetAccessibleName()
 		
