@@ -12,26 +12,26 @@
 import xml.dom.minidom as xml
 import math, os.path, sys
 import gtk, gobject
-from subprocess import call
+import webbrowser
 import Globals
 
 import gst
-if gst.pygst_version >= (0, 10, 10):
+try:	
 	import gst.pbutils
+	have_pbutils = True
+except:
+	have_pbutils = False
 
 # the highest range in decibels there can be between any two levels
 DECIBEL_RANGE = 80
 
+NANO_TO_MILLI_DIVISOR = gst.SECOND / 1000
+
 #_____________________________________________________________________
 
-def OpenExternalURL(url, message, parent):
+def OpenExternalURL(url, message, parent, timestamp=0):
 	"""
 	Opens a given url in the user's default web browser.
-	It'll try launchers in the following order:
-		xdg-open
-		gnome-open
-		kfmclient exec
-		exo-open
 		
 	Parameters:
 		url -- the url the user's default web browser will open.
@@ -39,25 +39,23 @@ def OpenExternalURL(url, message, parent):
 		parent -- parent window of the error message dialog.
 	"""
 		
-	for command in ("xdg-open", "gnome-open", "kfmclient exec", "exo-open"):
-		try:
-			#the next line will send the args as a list like: ["kfmclient", "exec", "http://www.jokosher.org/forums"]
-			retcode = call(command.split() + [url])
-			
-			#only return if the call was successful
-			if retcode == 0:
-				return
-		except OSError:
-			pass
-
-	dlg = gtk.MessageDialog(parent,
-			gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
-			gtk.MESSAGE_ERROR,
-			gtk.BUTTONS_CLOSE)
-	dlg.set_markup(message % url)
-	dlg.run()
-	dlg.destroy()
+	screen = gtk.gdk.screen_get_default()
+	ret = False
+	try:
+		ret = gtk.show_uri(screen, url, timestamp)
+	except:
+		ret = webbrowser.open(url)
 	
+	if not ret and message:
+		dlg = gtk.MessageDialog(parent,
+				gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
+				gtk.MESSAGE_ERROR,
+				gtk.BUTTONS_CLOSE)
+		dlg.set_markup(message % url)
+		dlg.run()
+		dlg.destroy()
+	
+	return ret
 #_____________________________________________________________________
 
 def GetIconThatMayBeMissing(iconName, iconSize, returnGtkImage=True):
@@ -111,7 +109,7 @@ def DbToFloat(f):
 
 #_____________________________________________________________________
 
-def CalculateAudioLevel(channelLevels):
+def CalculateAudioLevelFromStructure(structure):
 	"""
 	Calculates an average for all channel levels.
 	
@@ -122,10 +120,10 @@ def CalculateAudioLevel(channelLevels):
 		an average level, also taking into account negative infinity numbers,
 		which will be discarded in the average.
 	"""
-	if not channelLevels:
-		return 0
+	# FIXME: currently everything is being averaged to a single channel
+	channelLevels = structure["rms"]
 
-	negInf = float("-inf")
+	negInf = -1E+5000
 	peaktotal = 0
 	for peak in channelLevels:
 		#if peak > 0.001:
@@ -144,8 +142,11 @@ def CalculateAudioLevel(channelLevels):
 	peaktotal = max(peaktotal, -DECIBEL_RANGE)
 	peakint = int((peaktotal / DECIBEL_RANGE) * sys.maxint)
 
-	return peakint
+	endtime = structure["endtime"]
+	#convert number from gst.SECOND (i.e. nanoseconds) to milliseconds
+	endtime_millis = int(endtime / NANO_TO_MILLI_DIVISOR)
 
+	return (endtime_millis, [peakint])
 
 #_____________________________________________________________________
 
@@ -380,8 +381,8 @@ def StoreVariableToNode(value, node, typeAttr="type", valueAttr="value"):
 #_____________________________________________________________________
 
 def HandleGstPbutilsMissingMessage(message, callback, x_window_id=0):
-	# pbutils was wrapped in 0.10.10
-	if gst.pygst_version < (0, 10, 10):
+	# Not all platforms have pbutils
+	if not have_pbutils:
 		return False
 
 	#self._installing_plugins = True
